/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2010 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *******************************************************************************
 *
 * $Id: AbstractSelectionController.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.semantic.importexport;

import it.tidalwave.semantic.io.MIMETypes;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Arrays;
import java.util.List;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: AbstractSelectionController.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
public class AbstractSelectionController
  {
    public static final String PROP_FILE = "file";
    public static final String PROP_URL = "url";
    public static final String PROP_URLMIMETYPE = "urlMIMEType"; // FIXME: rename to MIMEType
    public static final String PROP_FILESELECTED = "fileSelected";
    public static final String PROP_URLSELECTED = "urlSelected";
    public static final String PROP_PROGRESSCOUNT = "progressCount";
    public static final String PROP_SIZE = "size";

    protected String file;
    protected String url;
    protected String urlMIMEType;
    protected boolean fileSelected;
    protected boolean urlSelected;
    protected int progressCount;
    protected int size;

    private final PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    //////// PROPERTIES ////////////////////////////////////////////////////////

    public List<String> getMIMETypes()
      {
        return Arrays.asList(MIMETypes.N3, MIMETypes.RDF_XML);
      }

    public void setUrlSelected (boolean urlSelected)
      {
        boolean oldUrlSelected = this.urlSelected;
        this.urlSelected = urlSelected;
        propertyChangeSupport.firePropertyChange(PROP_URLSELECTED, oldUrlSelected, urlSelected);
      }

    public boolean isUrlSelected()
      {
        return urlSelected;
      }

    public void setFileSelected (boolean fileSelected)
      {
        boolean oldFileSelected = this.fileSelected;
        this.fileSelected = fileSelected;
        propertyChangeSupport.firePropertyChange(PROP_FILESELECTED, oldFileSelected, fileSelected);
      }

    public boolean isFileSelected()
      {
        return fileSelected;
      }

    public void setUrlMIMEType (String urlMIMEType)
      {
        String oldUrlMIMEType = this.urlMIMEType;
        this.urlMIMEType = urlMIMEType;
        propertyChangeSupport.firePropertyChange(PROP_URLMIMETYPE, oldUrlMIMEType, urlMIMEType);
      }

    public String getUrlMIMEType()
      {
        return urlMIMEType;
      }

    public void setUrl (String url)
      {
        String oldUrl = this.url;
        this.url = url;
        propertyChangeSupport.firePropertyChange(PROP_URL, oldUrl, url);
      }

    public String getUrl()
      {
        return url;
      }

    public void setFile (String file)
      {
        String oldFile = this.file;
        this.file = file;
        propertyChangeSupport.firePropertyChange(PROP_FILE, oldFile, file);
      }

    public String getFile()
      {
        return file;
      }

    public void setProgressCount (int progressCount)
      {
        int oldProgressCount = this.progressCount;
        this.progressCount = progressCount;
        propertyChangeSupport.firePropertyChange(PROP_PROGRESSCOUNT, oldProgressCount, progressCount);
      }

    public int getProgressCount()
      {
        return progressCount;
      }

    public void setSize (int size)
      {
        int oldSize = this.size;
        this.size = size;
        propertyChangeSupport.firePropertyChange(PROP_SIZE, oldSize, size);
      }

    public int getSize()
      {
        return size;
      }

    public void addPropertyChangeListener (PropertyChangeListener listener)
      {
        propertyChangeSupport.addPropertyChangeListener(listener);
      }

    public void removePropertyChangeListener (PropertyChangeListener listener)
      {
        propertyChangeSupport.removePropertyChangeListener(listener);
      }
  }
