/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2010 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *******************************************************************************
 *
 * $Id: ExportRepositoryAction.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.semantic.importexport.action;

import javax.annotation.Nonnull;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import org.jdesktop.beansbinding.BindingGroup;
import it.tidalwave.util.logging.Logger;
import it.tidalwave.openide.DialogRunner;
import it.tidalwave.semantic.importexport.ExportTargetSelectionController;
import it.tidalwave.semantic.importexport.ExportTargetSelectionPanel;
import it.tidalwave.semantic.importexport.ByteCountProgressPanel;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: ExportRepositoryAction.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
public final class ExportRepositoryAction implements ActionListener
  {
    private final static String CLASS = ExportRepositoryAction.class.getName();
    private final static Logger logger = Logger.getLogger(CLASS);

    public void actionPerformed (@Nonnull final ActionEvent event)
      {
        final ExportTargetSelectionPanel panel = new ExportTargetSelectionPanel();

        if (DialogRunner.runOkCancelModalDialog(panel, "Select the target to export data to"))
          {
            try
              {
                final ExportTargetSelectionController controller = panel.getController();
                final ByteCountProgressPanel progressPanel = new ByteCountProgressPanel();
                final BindingGroup bindings = progressPanel.bind(controller, controller.PROP_PROGRESSCOUNT, controller.PROP_SIZE);

                DialogRunner.runTaskDialog(progressPanel, "Writing", new DialogRunner.Task()
                  {
                    public void run()
                      throws Exception
                      {
                        try
                          {
                            controller.doExport();
                          }
                        finally
                          {
                            bindings.unbind(); // FIXME: must it be the EDT?
                          }
                      }
                  });
              }
            catch (Throwable e)
              {
                logger.severe("While exporting: %s", e.toString());
                logger.throwing(CLASS, "doExport()", e);
                DialogRunner.showError("Error", e.toString());
              }
          }
      }
  }
